#include "nsISupports.idl"

interface nsIX509Cert;
interface nsIInterfaceRequestor;

[scriptable, uuid(5c6846c6-ccf9-11db-8314-0800200c9a66)]
interface rmdIBadCertHandler : nsISupports {

   boolean confirmMismatchDomain(in nsIInterfaceRequestor socketInfo,
                                 in AUTF8String targetURL,
                                 in nsIX509Cert cert);

   boolean confirmUnknownIssuer(in nsIInterfaceRequestor socketInfo, 
                                in nsIX509Cert cert,
                                out short certAddType);

 boolean confirmCertExpired(in nsIInterfaceRequestor socketInfo,
                            in nsIX509Cert cert);

 void notifyCrlNextupdate(in nsIInterfaceRequestor socketInfo,
                          in AUTF8String targetURL, 
			  in nsIX509Cert cert);

};
